###################################################################################################
#                              MIT Licence (C) 2022 Cubicpath@Github                              #
###################################################################################################
"""An unofficial GUI app for ChatGPT."""
# TODO: Remove pyright comments when PySide6 signals and events are properly type hinted.
from ._version import __version__
from ._version import __version_info__

__author__ = 'Cubicpath@Github <cubicpath@pm.me>'
"""Author's information."""
